-- Pull in the wezterm API
local wezterm = require 'wezterm'

-- This table will hold the configuration.
local config = {}

-- In newer versions of wezterm, use the config_builder which will
-- help provide clearer error messages
if wezterm.config_builder then
  config = wezterm.config_builder()
end

-- This is where you actually apply your config choices

-- Selenized colors by Alan Orth
-- With Lua help from: https://github.com/gfguthrie/wezterm-canonical-solarized/blob/main/canonical_solarized.lua
config.colors = {
  -- The default text color
  foreground = '#adbcbc',
  -- The default background color
  background = '#103c48',

  -- Overrides the cell background color when the current cell is occupied by the
  -- cursor and the cursor style is set to Block
  cursor_bg = '#53d6c7',
  -- Overrides the text color when the current cell is occupied by the cursor
  cursor_fg = '#103c48',
  -- Specifies the border color of the cursor when the cursor style is set to Block,
  -- or the color of the vertical or horizontal bar when the cursor style is set to
  -- Bar or Underline.
  cursor_border = '#52ad70',

  -- the foreground color of selected text (disabled for Solarized / Selenized)
  selection_fg = 'none',
  -- the background color of selected text
  selection_bg = '#184956',

  -- The color of the scrollbar "thumb"; the portion that represents the current viewport
  scrollbar_thumb = '#222222',

  -- The color of the split lines between panes
  split = '#84c747',

  ansi = {
    '#184956',
    '#fa5750',
    '#75b938',
    '#dbb32d',
    '#4695f7',
    '#f275be',
    '#41c7b9',
    '#72898f',
  },
  brights = {
    '#2d5b69',
    '#ff665c',
    '#84c747',
    '#ebc13d',
    '#58a3ff',
    '#ff84cd',
    '#53d6c7',
    '#cad8d9',
  },
}

-- Disable bold colors for Solarized / Selenized
config.bold_brightens_ansi_colors = false
config.hide_tab_bar_if_only_one_tab = true

-- Disable default padding
config.window_padding = {
  left = 0,
  right = 0,
  top = 0,
  bottom = 0,
}

-- and finally, return the configuration to wezterm
return config
